WELL_MAP <-
structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose", 
"D-Cellobiose", "Gentiobiose", "Sucrose", "D-Turanose", "Stachyose", 
"Positive Control", "pH 6", "pH 5", "D-Raffinose", "a-D-Lactose", 
"D-Melibiose", "b-Methyl-D-Galactoside", "D-Salicin", "N-Acetyl-D-Glucosamine", 
"N-Acetyl-b-D-Mannosamine", "N-Acetyl-D-Galactosamine", "N-Acetyl-Neuraminic Acid", 
"1% NaCl", "4% NaCl", "8% NaCl", "a-D-Glucose", "D-Mannose", 
"D-Fructose", "D-Galactose", "3-O-Methyl-Glucose", "D-Fucose", 
"L-Fucose", "L-Rhamnose", "Inosine", "1% Sodium Lactate", "Fusidic Acid", 
"D-Serine", "D-Sorbitol", "D-Mannitol", "D-Arabitol", "myo-Inositol", 
"Glycerol", "D-Glucose-6-Phosphate", "D-Fructose-6-Phosphate", 
"D-Aspartic Acid", "D-Serine", "Troleandomycin", "Rifamycin SV", 
"Minocycline", "Gelatin", "Glycyl-L-Proline", "L-Alanine", "L-Arginine", 
"L-Aspartic Acid", "L-Glutamic Acid", "L-Histidine", "L-Pyroglutamic Acid", 
"L-Serine", "Lincomycin", "Guanidine Hydrochloride", "Niaproof 4", 
"Pectin", "D-Galacturonic Acid", "L-Galactonic Acid-g-Lactone", 
"D-Gluconic Acid", "D-Glucuronic Acid", "Glucuronamide", "Mucic Acid", 
"Quinic Acid", "D-Saccharic Acid", "Vancomycin", "Tetrazolium Violet", 
"Tetrazolium Blue", "p-Hydroxy-Phenylacetic Acid", "Methyl Pyruvate", 
"D-Lactic Acid Methyl Ester", "L-Lactic Acid", "Citric Acid", 
"a-Keto-Glutaric Acid", "D-Malic Acid", "L-Malic Acid", "Bromo-Succinic Acid", 
"Nalidixic Acid", "Lithium Chloride", "Potassium Tellurite", 
"Tween 40", "g-Amino-Butyric Acid", "a-Hydroxy-Butyric Acid", 
"b-Hydroxy-Butyric Acid", "a-Keto-Butyric Acid", "Acetoacetic Acid", 
"Propionic Acid", "Acetic Acid", "Formic Acid", "Aztreonam", 
"Sodium Butyrate", "Sodium Bromate", "Negative Control", "L-Arabinose", 
"N-Acetyl-D-Glucosamine", "D-Saccharic Acid", "Succinic Acid", 
"D-Galactose", "L-Aspartic Acid", "L-Proline", "D-Alanine", "D-Trehalose", 
"D-Mannose", "Dulcitol", "D-Serine", "D-Sorbitol", "Glycerol", 
"L-Fucose", "D-Glucuronic Acid", "D-Gluconic Acid", "D,L-a-Glycerol-Phosphate", 
"D-Xylose", "L-Lactic Acid", "Formic Acid", "D-Mannitol", "L-Glutamic Acid", 
"D-Glucose-6-Phosphate", "D-Galactonic Acid-g-Lactone", "D,L-Malic Acid", 
"D-Ribose", "Tween 20", "L-Rhamnose", "D-Fructose", "Acetic Acid", 
"a-D-Glucose", "Maltose", "D-Melibiose", "Thymidine", "L-Asparagine", 
"D-Aspartic Acid", "D-Glucosaminic Acid", "1,2-Propanediol", 
"Tween 40", "a-Keto-Glutaric Acid", "a-Keto-Butyric Acid", "a-Methyl-D-Galactoside", 
"a-D-Lactose", "Lactulose", "Sucrose", "Uridine", "L-Glutamine", 
"m-Tartaric Acid", "D-Glucose-1-Phosphate", "D-Fructose-6-Phosphate", 
"Tween 80", "a-Hydroxy-Glutaric Acid-g-Lactone", "a-Hydroxy-Butyric Acid", 
"b-Methyl-D-Glucoside", "Adonitol", "Maltotriose", "2'-Deoxy-Adenosine", 
"Adenosine", "Glycyl-L-Aspartic Acid", "Citric Acid", "m-Inositol", 
"D-Threonine", "Fumaric Acid", "Bromo-Succinic Acid", "Propionic Acid", 
"Mucic Acid", "Glycolic Acid", "Glyoxylic Acid", "D-Cellobiose", 
"Inosine", "Glycyl-L-Glutamic Acid", "Tricarballylic Acid", "L-Serine", 
"L-Threonine", "L-Alanine", "L-Alanyl-Glycine", "Acetoacetic Acid", 
"N-Acetyl-b-D-Mannosamine", "Mono-Methyl Succinate", "Methyl Pyruvate", 
"D-Malic Acid", "L-Malic Acid", "Glycyl-L-Proline", "p-Hydroxy-Phenylacetic Acid", 
"m-Hydroxy-Phenylacetic Acid", "Tyramine", "D-Psicose", "L-Lyxose", 
"Glucuronamide", "Pyruvic Acid", "L-Galactonic Acid-g-Lactone", 
"D-Galacturonic Acid", "b-Phenylethylamine", "Ethanolamine", 
"Negative Control", "Chondroitin Sulfate C", "a-Cyclodextrin", 
"b-Cyclodextrin", "g-Cyclodextrin", "Dextrin", "Gelatin", "Glycogen", 
"Inulin", "Laminarin", "Mannan", "Pectin", "N-Acetyl-D-Galactosamine", 
"N-Acetyl-Neuraminic Acid", "b-D-Allose", "Amygdalin", "D-Arabinose", 
"D-Arabitol", "L-Arabitol", "Arbutin", "2-Deoxy-D-Ribose", "i-Erythritol", 
"D-Fucose", "3-O-b-D-Galactopyranosyl-D-Arabinose", "Gentiobiose", 
"L-Glucose", "D-Lactitol", "D-Melezitose", "Maltitol", "a-Methyl-D-Glucoside", 
"b-Methyl-D-Galactoside", "3-O-Methyl-Glucose", "b-Methyl-D-Glucuronic Acid", 
"a-Methyl-D-Mannoside", "b-Methyl-D-Xyloside", "Palatinose", 
"D-Raffinose", "Salicin", "Sedoheptulosan", "L-Sorbose", "Stachyose", 
"D-Tagatose", "Turanose", "Xylitol", "N-Acetyl-D-Glucosaminitol", 
"g-Amino-Butyric Acid", "d-Amino-Valeric Acid", "Butyric Acid", 
"Capric Acid", "Caproic Acid", "Citraconic Acid", "D-Citramalic Acid", 
"D-Glucosamine", "2-Hydroxy-Benzoic Acid", "4-Hydroxy-Benzoic Acid", 
"b-Hydroxy-Butyric Acid", "g-Hydroxy-Butyric Acid", "a-Keto-Valeric Acid", 
"Itaconic Acid", "5-Keto-D-Gluconic Acid", "D-Lactic Acid Methyl Ester", 
"Malonic Acid", "Melibionic Acid", "Oxalic Acid", "Oxalomalic Acid", 
"Quinic Acid", "D-Ribono-1,4-Lactone", "Sebacic Acid", "Sorbic Acid", 
"Succinamic Acid", "D-Tartaric Acid", "L-Tartaric Acid", "Acetamide", 
"L-Alaninamide", "N-Acetyl-L-Glutamic Acid", "L-Arginine", "Glycine", 
"L-Histidine", "L-Homoserine", "4-Hydroxy-L-Proline (trans)", 
"L-Isoleucine", "L-Leucine", "L-Lysine", "L-Methionine", "L-Ornithine", 
"L-Phenylalanine", "L-Pyroglutamic Acid", "L-Valine", "D,L-Carnitine", 
"Butylamine (sec)", "D,L-Octopamine", "Putrescine", "Dihydroxy-Acetone", 
"2,3-Butanediol", "2,3-Butanedione", "3-Hydroxy-2-Butanone", 
"Negative Control", "Ammonia", "Nitrite", "Nitrate", "Urea", 
"Biuret", "L-Alanine", "L-Arginine", "L-Asparagine", "L-Aspartic Acid", 
"L-Cysteine", "L-Glutamic Acid", "L-Glutamine", "Glycine", "L-Histidine", 
"L-Isoleucine", "L-Leucine", "L-Lysine", "L-Methionine", "L-Phenylalanine", 
"L-Proline", "L-Serine", "L-Threonine", "L-Tryptophan", "L-Tyrosine", 
"L-Valine", "D-Alanine", "D-Asparagine", "D-Aspartic Acid", "D-Glutamic Acid", 
"D-Lysine", "D-Serine", "D-Valine", "L-Citrulline", "L-Homoserine", 
"L-Ornithine", "N-Acetyl-L-Glutamic Acid", "N-Phthaloyl-L-Glutamic Acid", 
"L-Pyroglutamic Acid", "Hydroxylamine", "Methylamine", "N-Amylamine", 
"N-Butylamine", "Ethylamine", "Ethanolamine", "Ethylenediamine", 
"Putrescine", "Agmatine", "Histamine", "b-Phenylethylamine", 
"Tyramine", "Acetamide", "Formamide", "Glucuronamide", "D,L-Lactamide", 
"D-Glucosamine", "D-Galactosamine", "D-Mannosamine", "N-Acetyl-D-Glucosamine", 
"N-Acetyl-D-Galactosamine", "N-Acetyl-D-Mannosamine", "Adenine", 
"Adenosine", "Cytidine", "Cytosine", "Guanine", "Guanosine", 
"Thymine", "Thymidine", "Uracil", "Uridine", "Inosine", "Xanthine", 
"Xanthosine", "Uric Acid", "Alloxan", "Allantoin", "Parabanic Acid", 
"D,L-a-Amino-N-Butyric Acid", "g-Amino-N-Butyric Acid", "e-Amino-N-Caproic Acid", 
"D,L-a-Amino-Caprylic Acid", "d-Amino-N-Valeric Acid", "a-Amino-N-Valeric Acid", 
"Ala-Asp", "Ala-Gln", "Ala-Glu", "Ala-Gly", "Ala-His", "Ala-Leu", 
"Ala-Thr", "Gly-Asn", "Gly-Gln", "Gly-Glu", "Gly-Met", "Met-Ala", 
"Negative Control", "Phosphate", "Pyrophosphate", "Trimetaphosphate", 
"Tripolyphosphate", "Triethyl Phosphate", "Hypophosphite", "Adenosine-2'-Monophosphate", 
"Adenosine-3'-Monophosphate", "Adenosine-5'-Monophosphate", "Adenosine-2',3'-Cyclic Monophosphate", 
"Adenosine-3',5'-Cyclic Monophosphate", "Thiophosphate", "Dithiophosphate", 
"D,L-a-Glycerol-Phosphate", "b-Glycerol Phosphate", "Carbamyl Phosphate", 
"D-2-Phospho-Glyceric Acid", "D-3-Phospho-Glyceric Acid", "Guanosine-2'-Monophosphate", 
"Guanosine-3'-Monophosphate", "Guanosine-5'-Monophosphate", "Guanosine-2',3'-Cyclic Monophosphate", 
"Guanosine-3',5'-Cyclic Monophosphate", "Phosphoenol Pyruvate", 
"Phospho-Glycolic Acid", "D-Glucose-1-Phosphate", "D-Glucose-6-Phosphate", 
"2-Deoxy-D-Glucose-6-Phosphate", "D-Glucosamine-6-Phosphate", 
"6-Phospho-Gluconic Acid", "Cytidine-2'-Monophosphate", "Cytidine-3'-Monophosphate", 
"Cytidine-5'-Monophosphate", "Cytidine-2',3'-Cyclic Monophosphate", 
"Cytidine-3',5'-Cyclic Monophosphate", "D-Mannose-1-Phosphate", 
"D-Mannose-6-Phosphate", "Cysteamine-S-Phosphate", "Phospho-L-Arginine", 
"O-Phospho-D-Serine", "O-Phospho-L-Serine", "O-Phospho-L-Threonine", 
"Uridine-2'-Monophosphate", "Uridine-3'-Monophosphate", "Uridine-5'-Monophosphate", 
"Uridine-2',3'-Cyclic Monophosphate", "Uridine-3',5'-Cyclic Monophosphate", 
"O-Phospho-D-Tyrosine", "O-Phospho-L-Tyrosine", "Phosphocreatine", 
"Phosphoryl Choline", "O-Phosphoryl-Ethanolamine", "Phosphono Acetic Acid", 
"2-Aminoethyl Phosphonic Acid", "Methylene Diphosphonic Acid", 
"Thymidine-3'-Monophosphate", "Thymidine-5'-Monophosphate", "Inositol Hexaphosphate", 
"Thymidine 3',5'-Cyclic Monophosphate", "Negative Control", "Sulfate", 
"Thiosulfate", "Tetrathionate", "Thiophosphate", "Dithiophosphate", 
"L-Cysteine", "D-Cysteine", "L-Cysteinyl-Glycine", "L-Cysteic Acid", 
"Cysteamine", "L-Cysteine Sulfinic Acid", "N-Acetyl-L-Cysteine", 
"S-Methyl-L-Cysteine", "Cystathionine", "Lanthionine", "Glutathione", 
"D,L-Ethionine", "L-Methionine", "D-Methionine", "Glycyl-L-Methionine", 
"N-Acetyl-D,L-Methionine", "L-Methionine Sulfoxide", "L-Methionine Sulfone", 
"L-Djenkolic Acid", "Thiourea", "1-Thio-b-D-Glucose", "D,L-Lipoamide", 
"Taurocholic Acid", "Taurine", "Hypotaurine", "p-Amino Benzene Sulfonic Acid", 
"Butane Sulfonic Acid", "2-Hydroxyethane Sulfonic Acid", "Methane Sulfonic Acid", 
"Tetramethylene Sulfone", "Negative Control", "Positive Control", 
"L-Alanine", "L-Arginine", "L-Asparagine", "L-Aspartic Acid", 
"L-Cysteine", "L-Glutamic Acid", "Adenosine-3',5'-Cyclic Monophosphate", 
"Adenine", "Adenosine", "2'-Deoxy-Adenosine", "L-Glutamine", 
"Glycine", "L-Histidine", "L-Isoleucine", "L-Leucine", "L-Lysine", 
"L-Methionine", "L-Phenylalanine", "Guanosine-3',5'-Cyclic Monophosphate", 
"Guanine", "Guanosine", "2'-Deoxy-Guanosine", "L-Proline", "L-Serine", 
"L-Threonine", "L-Tryptophan", "L-Tyrosine", "L-Valine", "L-Isoleucine + L-Valine", 
"4-Hydroxy-L-Proline (trans)", "(5)4-Amino-Imidazole-4(5)-Carboxamide", 
"Hypoxanthine", "Inosine", "2'-Deoxy-Inosine", "L-Ornithine", 
"L-Citrulline", "Chorismic Acid", "Shikimic Acid (-)", "L-Homoserine Lactone", 
"D-Alanine", "D-Aspartic Acid", "D-Glutamic Acid", "D,L-Diamino-Pimelic Acid", 
"Cytosine", "Cytidine", "2'-Deoxy-Cytidine", "Putrescine", "Spermidine", 
"Spermine", "Pyridoxine", "Pyridoxal", "Pyridoxamine", "b-Alanine", 
"D-Pantothenic Acid", "Orotic Acid", "Uracil", "Uridine", "2'-Deoxy-Uridine", 
"Quinolinic Acid", "Nicotinic Acid", "Nicotinamide", "b-Nicotinamide Adenine Dinucleotide", 
"d-Amino-Levulinic Acid", "Hematin", "Deferoxamine Mesylate", 
"D-(+)-Glucose", "N-Acetyl-D-Glucosamine", "Thymine", "Glutathione (reduced form)", 
"Thymidine", "Oxaloacetic Acid", "D-Biotin", "Cyanocobalamin", 
"p-Amino-Benzoic Acid", "Folic Acid", "Inosine + Thiamine", "Thiamine", 
"Thiamine Pyrophosphate", "Riboflavin", "Pyrrolo-Quinoline Quinone", 
"Menadione", "m-Inositol", "Butyric Acid", "D,L-a-Hydroxy-Butyric Acid", 
"a-Keto-Butyric Acid", "Caprylic Acid", "D,L-a-Lipoic Acid (oxidized form)", 
"D,L-Mevalonic Acid Lactone", "D,L-Carnitine", "Choline", "Tween 20", 
"Tween 40", "Tween 60", "Tween 80", "Negative Control", "L-Glutamine", 
"Ala-Ala", "Ala-Arg", "Ala-Asn", "Ala-Glu", "Ala-Gly", "Ala-His", 
"Ala-Leu", "Ala-Lys", "Ala-Phe", "Ala-Pro", "Ala-Ser", "Ala-Thr", 
"Ala-Trp", "Ala-Tyr", "Arg-Ala", "Arg-Arg", "Arg-Asp", "Arg-Gln", 
"Arg-Glu", "Arg-Ile", "Arg-Leu", "Arg-Lys", "Arg-Met", "Arg-Phe", 
"Arg-Ser", "Arg-Trp", "Arg-Tyr", "Arg-Val", "Asn-Glu", "Asn-Val", 
"Asp-Asp", "Asp-Glu", "Asp-Leu", "Asp-Lys", "Asp-Phe", "Asp-Trp", 
"Asp-Val", "Cys-Gly", "Gln-Gln", "Gln-Gly", "Glu-Asp", "Glu-Glu", 
"Glu-Gly", "Glu-Ser", "Glu-Trp", "Glu-Tyr", "Glu-Val", "Gly-Ala", 
"Gly-Arg", "Gly-Cys", "Gly-Gly", "Gly-His", "Gly-Leu", "Gly-Lys", 
"Gly-Met", "Gly-Phe", "Gly-Pro", "Gly-Ser", "Gly-Thr", "Gly-Trp", 
"Gly-Tyr", "Gly-Val", "His-Asp", "His-Gly", "His-Leu", "His-Lys", 
"His-Met", "His-Pro", "His-Ser", "His-Trp", "His-Tyr", "His-Val", 
"Ile-Ala", "Ile-Arg", "Ile-Gln", "Ile-Gly", "Ile-His", "Ile-Ile", 
"Ile-Met", "Ile-Phe", "Ile-Pro", "Ile-Ser", "Ile-Trp", "Ile-Tyr", 
"Ile-Val", "Leu-Ala", "Leu-Arg", "Leu-Asp", "Leu-Glu", "Leu-Gly", 
"Leu-Ile", "Leu-Leu", "Leu-Met", "Leu-Phe", "Negative Control", 
"L-Glutamine", "Leu-Ser", "Leu-Trp", "Leu-Val", "Lys-Ala", "Lys-Arg", 
"Lys-Glu", "Lys-Ile", "Lys-Leu", "Lys-Lys", "Lys-Phe", "Lys-Pro", 
"Lys-Ser", "Lys-Thr", "Lys-Trp", "Lys-Tyr", "Lys-Val", "Met-Arg", 
"Met-Asp", "Met-Gln", "Met-Glu", "Met-Gly", "Met-His", "Met-Ile", 
"Met-Leu", "Met-Lys", "Met-Met", "Met-Phe", "Met-Pro", "Met-Trp", 
"Met-Val", "Phe-Ala", "Phe-Gly", "Phe-Ile", "Phe-Phe", "Phe-Pro", 
"Phe-Ser", "Phe-Trp", "Pro-Ala", "Pro-Asp", "Pro-Gln", "Pro-Gly", 
"Pro-Hyp", "Pro-Leu", "Pro-Phe", "Pro-Pro", "Pro-Tyr", "Ser-Ala", 
"Ser-Gly", "Ser-His", "Ser-Leu", "Ser-Met", "Ser-Phe", "Ser-Pro", 
"Ser-Ser", "Ser-Tyr", "Ser-Val", "Thr-Ala", "Thr-Arg", "Thr-Glu", 
"Thr-Gly", "Thr-Leu", "Thr-Met", "Thr-Pro", "Trp-Ala", "Trp-Arg", 
"Trp-Asp", "Trp-Glu", "Trp-Gly", "Trp-Leu", "Trp-Lys", "Trp-Phe", 
"Trp-Ser", "Trp-Trp", "Trp-Tyr", "Tyr-Ala", "Tyr-Gln", "Tyr-Glu", 
"Tyr-Gly", "Tyr-His", "Tyr-Leu", "Tyr-Lys", "Tyr-Phe", "Tyr-Trp", 
"Tyr-Tyr", "Val-Arg", "Val-Asn", "Val-Asp", "Val-Gly", "Val-His", 
"Val-Ile", "Val-Leu", "Val-Tyr", "Val-Val", "g-Glu-Gly", "Negative Control", 
"L-Glutamine", "Ala-Asp", "Ala-Gln", "Ala-Ile", "Ala-Met", "Ala-Val", 
"Asp-Ala", "Asp-Gln", "Asp-Gly", "Glu-Ala", "Gly-Asn", "Gly-Asp", 
"Gly-Ile", "His-Ala", "His-Glu", "His-His", "Ile-Asn", "Ile-Leu", 
"Leu-Asn", "Leu-His", "Leu-Pro", "Leu-Tyr", "Lys-Asp", "Lys-Gly", 
"Lys-Met", "Met-Thr", "Met-Tyr", "Phe-Asp", "Phe-Glu", "Gln-Glu", 
"Phe-Met", "Phe-Tyr", "Phe-Val", "Pro-Arg", "Pro-Asn", "Pro-Glu", 
"Pro-Ile", "Pro-Lys", "Pro-Ser", "Pro-Trp", "Pro-Val", "Ser-Asn", 
"Ser-Asp", "Ser-Gln", "Ser-Glu", "Thr-Asp", "Thr-Gln", "Thr-Phe", 
"Thr-Ser", "Trp-Val", "Tyr-Ile", "Tyr-Val", "Val-Ala", "Val-Gln", 
"Val-Glu", "Val-Lys", "Val-Met", "Val-Phe", "Val-Pro", "Val-Ser", 
"b-Ala-Ala", "b-Ala-Gly", "b-Ala-His", "Met-b-Ala", "b-Ala-Phe", 
"D-Ala-D-Ala", "D-Ala-Gly", "D-Ala-Leu", "D-Leu-D-Leu", "D-Leu-Gly", 
"D-Leu-Tyr", "g-Glu-Gly", "g-D-Glu-Gly", "Gly-D-Ala", "Gly-D-Asp", 
"Gly-D-Ser", "Gly-D-Thr", "Gly-D-Val", "Leu-b-Ala", "Leu-D-Leu", 
"Phe-b-Ala", "Ala-Ala-Ala", "D-Ala-Gly-Gly", "Gly-Gly-Ala", "Gly-Gly-D-Leu", 
"Gly-Gly-Gly", "Gly-Gly-Ile", "Gly-Gly-Leu", "Gly-Gly-Phe", "Val-Tyr-Val", 
"Gly-Phe-Phe", "Leu-Gly-Gly", "Leu-Leu-Leu", "Phe-Gly-Gly", "Tyr-Gly-Gly", 
"1% NaCl", "2% NaCl", "3% NaCl", "4% NaCl", "5% NaCl", "5.5% NaCl", 
"6% NaCl", "6.5% NaCl", "7% NaCl", "8% NaCl", "9% NaCl", "10% NaCl", 
"6% NaCl", "6% NaCl + Betaine", "6% NaCl + N-N Dimethyl Glycine", 
"6% NaCl + Sarcosine", "6% NaCl + Dimethyl Sulphonyl Propionate", 
"6% NaCl + MOPS", "6% NaCl + Ectoine", "6% NaCl + Choline", "6% NaCl + Phosphorylcholine", 
"6% NaCl + Creatine", "6% NaCl + Creatinine", "6% NaCl + L-Carnitine", 
"6% NaCl + KCl", "6% NaCl + L-Proline", "6% NaCl + N-Acetyl-L-Glutamine", 
"6% NaCl + b-Glutamic Acid", "6% NaCl + g-Amino-N-Butyric Acid", 
"6% NaCl + Glutathione", "6% NaCl + Glycerol", "6% NaCl + Trehalose", 
"6% NaCl + Trimethylamine-N-Oxide", "6% NaCl + Trimethylamine", 
"6% NaCl + Octopine", "6% NaCl + Trigonelline", "3% Potassium Chloride", 
"4% Potassium Chloride", "5% Potassium Chloride", "6% Potassium Chloride", 
"2% Sodium Sulfate", "3% Sodium Sulfate", "4% Sodium Sulfate", 
"5% Sodium Sulfate", "5% Ethylene Glycol", "10% Ethylene Glycol", 
"15% Ethylene Glycol", "20% Ethylene Glycol", "1% Sodium Formate", 
"2% Sodium Formate", "3% Sodium Formate", "4% Sodium Formate", 
"5% Sodium Formate", "6% Sodium Formate", "2% Urea", "3% Urea", 
"4% Urea", "5% Urea", "6% Urea", "7% Urea", "1% Sodium Lactate", 
"2% Sodium Lactate", "3% Sodium Lactate", "4% Sodium Lactate", 
"5% Sodium Lactate", "6% Sodium Lactate", "7% Sodium Lactate", 
"8% Sodium Lactate", "9% Sodium Lactate", "10% Sodium Lactate", 
"11% Sodium Lactate", "12% Sodium Lactate", "20mM Sodium Phosphate pH 7", 
"50mM Sodium Phosphate pH 7", "100mM Sodium Phosphate pH 7", 
"200mM Sodium Phosphate pH 7", "20mM Sodium Benzoate pH 5.2", 
"50mM Sodium Benzoate pH 5.2", "100mM Sodium Benzoate pH 5.2", 
"200mM Sodium Benzoate pH 5.2", "10mM Ammonium Sulfate pH 8", 
"20mM Ammonium Sulfate pH 8", "50mM Ammonium Sulfate pH 8", "100mM Ammonium Sulfate pH 8", 
"10mM Sodium Nitrate", "20mM Sodium Nitrate", "40mM Sodium Nitrate", 
"60mM Sodium Nitrate", "80mM Sodium Nitrate", "100mM Sodium Nitrate", 
"10mM Sodium Nitrite", "20mM Sodium Nitrite", "40mM Sodium Nitrite", 
"60mM Sodium Nitrite", "80mM Sodium Nitrite", "100mM Sodium Nitrite", 
"pH 3.5", "pH 4", "pH 4.5", "pH 5", "pH 5.5", "pH 6", "pH 7", 
"pH 8", "pH 8.5", "pH 9", "pH 9.5", "pH 10", "pH 4.5", "pH 4.5 + L-Alanine", 
"pH 4.5 + L-Arginine", "pH 4.5 + L-Asparagine", "pH 4.5 + L-Aspartic Acid", 
"pH 4.5 + L-Glutamic Acid", "pH 4.5 + L-Glutamine", "pH 4.5 + Glycine", 
"pH 4.5 + L-Histidine", "pH 4.5 + L-Isoleucine", "pH 4.5 + L-Leucine", 
"pH 4.5 + L-Lysine", "pH 4.5 + L-Methionine", "pH 4.5 + L-Phenylalanine", 
"pH 4.5 + L-Proline", "pH 4.5 + L-Serine", "pH 4.5 + L-Threonine", 
"pH 4.5 + L-Tryptophan", "pH 4.5 + L-Citrulline", "pH 4.5 + L-Valine", 
"pH 4.5 + Hydroxy-L-Proline", "pH 4.5 + L-Ornithine", "pH 4.5 + L-Homoarginine", 
"pH 4.5 + L-Homoserine", "pH 4.5 + Anthranilic Acid", "pH 4.5 + L-Norleucine", 
"pH 4.5 + L-Norvaline", "pH 4.5 + a-Amino-N-Butyric Acid", "pH 4.5 + p-Aminobenzoic Acid", 
"pH 4.5 + L-Cysteic Acid", "pH 4.5 + D-Lysine", "pH 4.5 + 5-Hydroxy-L-Lysine", 
"pH 4.5 + 5-Hydroxy-L-Tryptophan", "pH 4.5 + D,L-Diamino-a,e-Pimelic Acid", 
"pH 4.5 + Trimethylamine-N-Oxide", "pH 4.5 + Urea", "pH 9.5", 
"pH 9.5 + L-Alanine", "pH 9.5 + L-Arginine", "pH 9.5 + L-Asparagine", 
"pH 9.5 + L-Aspartic Acid", "pH 9.5 + L-Glutamic Acid", "pH 9.5 + L-Glutamine", 
"pH 9.5 + Glycine", "pH 9.5 + L-Histidine", "pH 9.5 + L-Isoleucine", 
"pH 9.5 + L-Leucine", "pH 9.5 + L-Lysine", "pH 9.5 + L-Methionine", 
"pH 9.5 + L-Phenylalanine", "pH 9.5 + L-Proline", "pH 9.5 + L-Serine", 
"pH 9.5 + L-Threonine", "pH 9.5 + L-Tryptophan", "pH 9.5 + L-Tyrosine", 
"pH 9.5 + L-Valine", "pH 9.5 + Hydroxy-L-Proline", "pH 9.5 + L-Ornithine", 
"pH 9.5 + L-Homoarginine", "pH 9.5 + L-Homoserine", "pH 9.5 + Anthranilic Acid", 
"pH 9.5 + L-Norleucine", "pH 9.5 + L-Norvaline", "pH 9.5 + Agmatine", 
"pH 9.5 + Cadaverine", "pH 9.5 + Putrescine", "pH 9.5 + Histamine", 
"pH 9.5 + b-Phenylethylamine", "pH 9.5 + Tyramine", "pH 9.5 + Creatine", 
"pH 9.5 + Trimethylamine-N-Oxide", "pH 9.5 + Urea", "X-Caprylate", 
"X-a-D-Glucoside", "X-b-D-Glucoside", "X-a-D-Galactoside", "X-b-D-Galactoside", 
"X-a-D-Glucuronide", "X-b-D-Glucuronide", "X-b-D-Glucosaminide", 
"X-b-D-Galactosaminide", "X-a-D-Mannoside", "X-PO4", "X-SO4", 
"Amikacin", "Amikacin", "Amikacin", "Amikacin", "Chlortetracycline", 
"Chlortetracycline", "Chlortetracycline", "Chlortetracycline", 
"Lincomycin", "Lincomycin", "Lincomycin", "Lincomycin", "Amoxicillin", 
"Amoxicillin", "Amoxicillin", "Amoxicillin", "Cloxacillin", "Cloxacillin", 
"Cloxacillin", "Cloxacillin", "Lomefloxacin", "Lomefloxacin", 
"Lomefloxacin", "Lomefloxacin", "Bleomycin", "Bleomycin", "Bleomycin", 
"Bleomycin", "Colistin", "Colistin", "Colistin", "Colistin", 
"Minocycline", "Minocycline", "Minocycline", "Minocycline", "Capreomycin", 
"Capreomycin", "Capreomycin", "Capreomycin", "Demeclocycline", 
"Demeclocycline", "Demeclocycline", "Demeclocycline", "Nafcillin", 
"Nafcillin", "Nafcillin", "Nafcillin", "Cefazolin", "Cefazolin", 
"Cefazolin", "Cefazolin", "Enoxacin", "Enoxacin", "Enoxacin", 
"Enoxacin", "Nalidixic Acid", "Nalidixic Acid", "Nalidixic Acid", 
"Nalidixic Acid", "Chloramphenicol", "Chloramphenicol", "Chloramphenicol", 
"Chloramphenicol", "Erythromycin", "Erythromycin", "Erythromycin", 
"Erythromycin", "Neomycin", "Neomycin", "Neomycin", "Neomycin", 
"Ceftriaxone", "Ceftriaxone", "Ceftriaxone", "Ceftriaxone", "Gentamicin", 
"Gentamicin", "Gentamicin", "Gentamicin", "Potassium Tellurite", 
"Potassium Tellurite", "Potassium Tellurite", "Potassium Tellurite", 
"Cephalothin", "Cephalothin", "Cephalothin", "Cephalothin", "Kanamycin", 
"Kanamycin", "Kanamycin", "Kanamycin", "Ofloxacin", "Ofloxacin", 
"Ofloxacin", "Ofloxacin", "Penicillin G", "Penicillin G", "Penicillin G", 
"Penicillin G", "Tetracycline", "Tetracycline", "Tetracycline", 
"Tetracycline", "Carbenicillin", "Carbenicillin", "Carbenicillin", 
"Carbenicillin", "Oxacillin", "Oxacillin", "Oxacillin", "Oxacillin", 
"Penimepicycline", "Penimepicycline", "Penimepicycline", "Penimepicycline", 
"Polymyxin B", "Polymyxin B", "Polymyxin B", "Polymyxin B", "Paromomycin", 
"Paromomycin", "Paromomycin", "Paromomycin", "Vancomycin", "Vancomycin", 
"Vancomycin", "Vancomycin", "D,L-Serine Hydroxamate", "D,L-Serine Hydroxamate", 
"D,L-Serine Hydroxamate", "D,L-Serine Hydroxamate", "Sisomicin", 
"Sisomicin", "Sisomicin", "Sisomicin", "Sulfamethazine", "Sulfamethazine", 
"Sulfamethazine", "Sulfamethazine", "Novobiocin", "Novobiocin", 
"Novobiocin", "Novobiocin", "2,4-Diamino-6,7-Diisopropylpteridine", 
"2,4-Diamino-6,7-Diisopropylpteridine", "2,4-Diamino-6,7-Diisopropylpteridine", 
"2,4-Diamino-6,7-Diisopropylpteridine", "Sulfadiazine", "Sulfadiazine", 
"Sulfadiazine", "Sulfadiazine", "Benzethonium Chloride", "Benzethonium Chloride", 
"Benzethonium Chloride", "Benzethonium Chloride", "Tobramycin", 
"Tobramycin", "Tobramycin", "Tobramycin", "Sulfathiazole", "Sulfathiazole", 
"Sulfathiazole", "Sulfathiazole", "5-Fluoroorotic Acid", "5-Fluoroorotic Acid", 
"5-Fluoroorotic Acid", "5-Fluoroorotic Acid", "Spectinomycin", 
"Spectinomycin", "Spectinomycin", "Spectinomycin", "Sulfamethoxazole", 
"Sulfamethoxazole", "Sulfamethoxazole", "Sulfamethoxazole", "L-Aspartic-b-Hydroxamate", 
"L-Aspartic-b-Hydroxamate", "L-Aspartic-b-Hydroxamate", "L-Aspartic-b-Hydroxamate", 
"Spiramycin", "Spiramycin", "Spiramycin", "Spiramycin", "Rifampicin", 
"Rifampicin", "Rifampicin", "Rifampicin", "Dodecyltrimethyl Ammonium Bromide", 
"Dodecyltrimethyl Ammonium Bromide", "Dodecyltrimethyl Ammonium Bromide", 
"Dodecyltrimethyl Ammonium Bromide", "Ampicillin", "Ampicillin", 
"Ampicillin", "Ampicillin", "Dequalinium", "Dequalinium", "Dequalinium", 
"Dequalinium", "Nickel Chloride", "Nickel Chloride", "Nickel Chloride", 
"Nickel Chloride", "Azlocillin", "Azlocillin", "Azlocillin", 
"Azlocillin", "2,2'-Dipyridyl", "2,2'-Dipyridyl", "2,2'-Dipyridyl", 
"2,2'-Dipyridyl", "Oxolinic Acid", "Oxolinic Acid", "Oxolinic Acid", 
"Oxolinic Acid", "6-Mercaptopurine", "6-Mercaptopurine", "6-Mercaptopurine", 
"6-Mercaptopurine", "Doxycycline", "Doxycycline", "Doxycycline", 
"Doxycycline", "Potassium Chromate", "Potassium Chromate", "Potassium Chromate", 
"Potassium Chromate", "Cefuroxime", "Cefuroxime", "Cefuroxime", 
"Cefuroxime", "5-Fluorouracil", "5-Fluorouracil", "5-Fluorouracil", 
"5-Fluorouracil", "Rolitetracycline", "Rolitetracycline", "Rolitetracycline", 
"Rolitetracycline", "Cytarabine", "Cytarabine", "Cytarabine", 
"Cytarabine", "Geneticin (G418)", "Geneticin (G418)", "Geneticin (G418)", 
"Geneticin (G418)", "Ruthenium Red", "Ruthenium Red", "Ruthenium Red", 
"Ruthenium Red", "Cesium Chloride", "Cesium Chloride", "Cesium Chloride", 
"Cesium Chloride", "Glycine", "Glycine", "Glycine", "Glycine", 
"Thallium (I) Acetate", "Thallium (I) Acetate", "Thallium (I) Acetate", 
"Thallium (I) Acetate", "Cobalt (II) Chloride", "Cobalt (II) Chloride", 
"Cobalt (II) Chloride", "Cobalt (II) Chloride", "Manganese (II) Chloride", 
"Manganese (II) Chloride", "Manganese (II) Chloride", "Manganese (II) Chloride", 
"Trifluoperazine", "Trifluoperazine", "Trifluoperazine", "Trifluoperazine", 
"Cupric Chloride", "Cupric Chloride", "Cupric Chloride", "Cupric Chloride", 
"Moxalactam", "Moxalactam", "Moxalactam", "Moxalactam", "Tylosin", 
"Tylosin", "Tylosin", "Tylosin", "Acriflavine", "Acriflavine", 
"Acriflavine", "Acriflavine", "Furaltadone", "Furaltadone", "Furaltadone", 
"Furaltadone", "Sanguinarine", "Sanguinarine", "Sanguinarine", 
"Sanguinarine", "9-Aminoacridine", "9-Aminoacridine", "9-Aminoacridine", 
"9-Aminoacridine", "Fusaric Acid", "Fusaric Acid", "Fusaric Acid", 
"Fusaric Acid", "Sodium Arsenate", "Sodium Arsenate", "Sodium Arsenate", 
"Sodium Arsenate", "Boric Acid", "Boric Acid", "Boric Acid", 
"Boric Acid", "1-Hydroxy-Pyridine-2-Thione", "1-Hydroxy-Pyridine-2-Thione", 
"1-Hydroxy-Pyridine-2-Thione", "1-Hydroxy-Pyridine-2-Thione", 
"Sodium Cyanate", "Sodium Cyanate", "Sodium Cyanate", "Sodium Cyanate", 
"Cadmium Chloride", "Cadmium Chloride", "Cadmium Chloride", "Cadmium Chloride", 
"Iodoacetic Acid", "Iodoacetic Acid", "Iodoacetic Acid", "Iodoacetic Acid", 
"Sodium Dichromate", "Sodium Dichromate", "Sodium Dichromate", 
"Sodium Dichromate", "Cefoxitin", "Cefoxitin", "Cefoxitin", "Cefoxitin", 
"Nitrofurantoin", "Nitrofurantoin", "Nitrofurantoin", "Nitrofurantoin", 
"Sodium Metaborate", "Sodium Metaborate", "Sodium Metaborate", 
"Sodium Metaborate", "Chloramphenicol", "Chloramphenicol", "Chloramphenicol", 
"Chloramphenicol", "Piperacillin", "Piperacillin", "Piperacillin", 
"Piperacillin", "Sodium Metavanadate", "Sodium Metavanadate", 
"Sodium Metavanadate", "Sodium Metavanadate", "Chelerythrine", 
"Chelerythrine", "Chelerythrine", "Chelerythrine", "Carbenicillin", 
"Carbenicillin", "Carbenicillin", "Carbenicillin", "Sodium Nitrite", 
"Sodium Nitrite", "Sodium Nitrite", "Sodium Nitrite", "EGTA", 
"EGTA", "EGTA", "EGTA", "Promethazine", "Promethazine", "Promethazine", 
"Promethazine", "Sodium Orthovanadate", "Sodium Orthovanadate", 
"Sodium Orthovanadate", "Sodium Orthovanadate", "Procaine", "Procaine", 
"Procaine", "Procaine", "Guanidine Hydrochloride", "Guanidine Hydrochloride", 
"Guanidine Hydrochloride", "Guanidine Hydrochloride", "Cefmetazole", 
"Cefmetazole", "Cefmetazole", "Cefmetazole", "D-Cycloserine", 
"D-Cycloserine", "D-Cycloserine", "D-Cycloserine", "EDTA", "EDTA", 
"EDTA", "EDTA", "5,7-Dichloro-8-Hydroxy-Quinaldine", "5,7-Dichloro-8-Hydroxy-Quinaldine", 
"5,7-Dichloro-8-Hydroxy-Quinaldine", "5,7-Dichloro-8-Hydroxy-Quinaldine", 
"5,7-Dichloro-8-Hydroxyquinoline", "5,7-Dichloro-8-Hydroxyquinoline", 
"5,7-Dichloro-8-Hydroxyquinoline", "5,7-Dichloro-8-Hydroxyquinoline", 
"Fusidic Acid", "Fusidic Acid", "Fusidic Acid", "Fusidic Acid", 
"1,10-Phenanthroline", "1,10-Phenanthroline", "1,10-Phenanthroline", 
"1,10-Phenanthroline", "Phleomycin", "Phleomycin", "Phleomycin", 
"Phleomycin", "Domiphen Bromide", "Domiphen Bromide", "Domiphen Bromide", 
"Domiphen Bromide", "Nordihydroguaiaretic Acid", "Nordihydroguaiaretic Acid", 
"Nordihydroguaiaretic Acid", "Nordihydroguaiaretic Acid", "Alexidine", 
"Alexidine", "Alexidine", "Alexidine", "Nitrofurazone", "Nitrofurazone", 
"Nitrofurazone", "Nitrofurazone", "Methyl Viologen", "Methyl Viologen", 
"Methyl Viologen", "Methyl Viologen", "3,4-Dimethoxybenzyl Alcohol", 
"3,4-Dimethoxybenzyl Alcohol", "3,4-Dimethoxybenzyl Alcohol", 
"3,4-Dimethoxybenzyl Alcohol", "Oleandomycin", "Oleandomycin", 
"Oleandomycin", "Oleandomycin", "Puromycin", "Puromycin", "Puromycin", 
"Puromycin", "CCCP", "CCCP", "CCCP", "CCCP", "Sodium Azide", 
"Sodium Azide", "Sodium Azide", "Sodium Azide", "Menadione", 
"Menadione", "Menadione", "Menadione", "2-Nitroimidazole", "2-Nitroimidazole", 
"2-Nitroimidazole", "2-Nitroimidazole", "Hydroxyurea", "Hydroxyurea", 
"Hydroxyurea", "Hydroxyurea", "Zinc Chloride", "Zinc Chloride", 
"Zinc Chloride", "Zinc Chloride", "Cefotaxime", "Cefotaxime", 
"Cefotaxime", "Cefotaxime", "Phosphomycin", "Phosphomycin", "Phosphomycin", 
"Phosphomycin", "5-Chloro-7-Iodo-8-Hydroxyquinoline", "5-Chloro-7-Iodo-8-Hydroxyquinoline", 
"5-Chloro-7-Iodo-8-Hydroxyquinoline", "5-Chloro-7-Iodo-8-Hydroxyquinoline", 
"Norfloxacin", "Norfloxacin", "Norfloxacin", "Norfloxacin", "Sulfanilamide", 
"Sulfanilamide", "Sulfanilamide", "Sulfanilamide", "Trimethoprim", 
"Trimethoprim", "Trimethoprim", "Trimethoprim", "Dichlofluanid", 
"Dichlofluanid", "Dichlofluanid", "Dichlofluanid", "Protamine Sulfate", 
"Protamine Sulfate", "Protamine Sulfate", "Protamine Sulfate", 
"Cetylpyridinium Chloride", "Cetylpyridinium Chloride", "Cetylpyridinium Chloride", 
"Cetylpyridinium Chloride", "1-Chloro-2,4-Dinitrobenzene", "1-Chloro-2,4-Dinitrobenzene", 
"1-Chloro-2,4-Dinitrobenzene", "1-Chloro-2,4-Dinitrobenzene", 
"Diamide", "Diamide", "Diamide", "Diamide", "Cinoxacin", "Cinoxacin", 
"Cinoxacin", "Cinoxacin", "Streptomycin", "Streptomycin", "Streptomycin", 
"Streptomycin", "5-Azacytidine", "5-Azacytidine", "5-Azacytidine", 
"5-Azacytidine", "Rifamycin SV", "Rifamycin SV", "Rifamycin SV", 
"Rifamycin SV", "Potassium Tellurite", "Potassium Tellurite", 
"Potassium Tellurite", "Potassium Tellurite", "Sodium Selenite", 
"Sodium Selenite", "Sodium Selenite", "Sodium Selenite", "Aluminum Sulfate", 
"Aluminum Sulfate", "Aluminum Sulfate", "Aluminum Sulfate", "Chromium (III) Chloride", 
"Chromium (III) Chloride", "Chromium (III) Chloride", "Chromium (III) Chloride", 
"Ferric Chloride", "Ferric Chloride", "Ferric Chloride", "Ferric Chloride", 
"L-Glutamic Acid g-Hydroxamate", "L-Glutamic Acid g-Hydroxamate", 
"L-Glutamic Acid g-Hydroxamate", "L-Glutamic Acid g-Hydroxamate", 
"Glycine Hydroxamate", "Glycine Hydroxamate", "Glycine Hydroxamate", 
"Glycine Hydroxamate", "Chloroxylenol", "Chloroxylenol", "Chloroxylenol", 
"Chloroxylenol", "Sorbic Acid", "Sorbic Acid", "Sorbic Acid", 
"Sorbic Acid", "D-Serine", "D-Serine", "D-Serine", "D-Serine", 
"b-Chloro-L-Alanine", "b-Chloro-L-Alanine", "b-Chloro-L-Alanine", 
"b-Chloro-L-Alanine", "Thiosalicylate", "Thiosalicylate", "Thiosalicylate", 
"Thiosalicylate", "Salicylate", "Salicylate", "Salicylate", "Salicylate", 
"Hygromycin B", "Hygromycin B", "Hygromycin B", "Hygromycin B", 
"Ethionamide", "Ethionamide", "Ethionamide", "Ethionamide", "4-Aminopyridine", 
"4-Aminopyridine", "4-Aminopyridine", "4-Aminopyridine", "Sulfachloropyridazine", 
"Sulfachloropyridazine", "Sulfachloropyridazine", "Sulfachloropyridazine", 
"Sulfamonomethoxine", "Sulfamonomethoxine", "Sulfamonomethoxine", 
"Sulfamonomethoxine", "Oxycarboxin", "Oxycarboxin", "Oxycarboxin", 
"Oxycarboxin", "3-Amino-1,2,4-triazole", "3-Amino-1,2,4-triazole", 
"3-Amino-1,2,4-triazole", "3-Amino-1,2,4-triazole", "Chlorpromazine", 
"Chlorpromazine", "Chlorpromazine", "Chlorpromazine", "Niaproof", 
"Niaproof", "Niaproof", "Niaproof", "Compound 48/80", "Compound 48/80", 
"Compound 48/80", "Compound 48/80", "Sodium Tungstate", "Sodium Tungstate", 
"Sodium Tungstate", "Sodium Tungstate", "Lithium Chloride", "Lithium Chloride", 
"Lithium Chloride", "Lithium Chloride", "D,L-Methionine Hydroxamate", 
"D,L-Methionine Hydroxamate", "D,L-Methionine Hydroxamate", "D,L-Methionine Hydroxamate", 
"Tannic Acid", "Tannic Acid", "Tannic Acid", "Tannic Acid", "Chlorambucil", 
"Chlorambucil", "Chlorambucil", "Chlorambucil", "Cefamandole Nafate", 
"Cefamandole Nafate", "Cefamandole Nafate", "Cefamandole Nafate", 
"Cefoperazone", "Cefoperazone", "Cefoperazone", "Cefoperazone", 
"Cefsulodin", "Cefsulodin", "Cefsulodin", "Cefsulodin", "Caffeine", 
"Caffeine", "Caffeine", "Caffeine", "Phenylarsine Oxide", "Phenylarsine Oxide", 
"Phenylarsine Oxide", "Phenylarsine Oxide", "Ketoprofen", "Ketoprofen", 
"Ketoprofen", "Ketoprofen", "Sodium Pyrophosphate Decahydrate", 
"Sodium Pyrophosphate Decahydrate", "Sodium Pyrophosphate Decahydrate", 
"Sodium Pyrophosphate Decahydrate", "Thiamphenicol", "Thiamphenicol", 
"Thiamphenicol", "Thiamphenicol", "Trifluorothymidine", "Trifluorothymidine", 
"Trifluorothymidine", "Trifluorothymidine", "Pipemidic Acid", 
"Pipemidic Acid", "Pipemidic Acid", "Pipemidic Acid", "Azathioprine", 
"Azathioprine", "Azathioprine", "Azathioprine", "Poly-L-lysine", 
"Poly-L-lysine", "Poly-L-lysine", "Poly-L-lysine", "Sulfisoxazole", 
"Sulfisoxazole", "Sulfisoxazole", "Sulfisoxazole", "Pentachlorophenol", 
"Pentachlorophenol", "Pentachlorophenol", "Pentachlorophenol", 
"Sodium m-Arsenite", "Sodium m-Arsenite", "Sodium m-Arsenite", 
"Sodium m-Arsenite", "Sodium Bromate", "Sodium Bromate", "Sodium Bromate", 
"Sodium Bromate", "Lidocaine", "Lidocaine", "Lidocaine", "Lidocaine", 
"Sodium Metasilicate", "Sodium Metasilicate", "Sodium Metasilicate", 
"Sodium Metasilicate", "Sodium Periodate", "Sodium Periodate", 
"Sodium Periodate", "Sodium Periodate", "Antimony (III) Chloride", 
"Antimony (III) Chloride", "Antimony (III) Chloride", "Antimony (III) Chloride", 
"Semicarbazide Hydrochloride", "Semicarbazide Hydrochloride", 
"Semicarbazide Hydrochloride", "Semicarbazide Hydrochloride", 
"Tinidazole", "Tinidazole", "Tinidazole", "Tinidazole", "Aztreonam", 
"Aztreonam", "Aztreonam", "Aztreonam", "Triclosan", "Triclosan", 
"Triclosan", "Triclosan", "Guanazole", "Guanazole", "Guanazole", 
"Guanazole", "Myricetin", "Myricetin", "Myricetin", "Myricetin", 
"5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", 
"5-Fluoro-5'-Deoxyuridine", "2-Phenylphenol", "2-Phenylphenol", 
"2-Phenylphenol", "2-Phenylphenol", "Plumbagin", "Plumbagin", 
"Plumbagin", "Plumbagin", "Josamycin", "Josamycin", "Josamycin", 
"Josamycin", "Gallic Acid", "Gallic Acid", "Gallic Acid", "Gallic Acid", 
"Coumarin", "Coumarin", "Coumarin", "Coumarin", "Methyltrioctylammonium Chloride", 
"Methyltrioctylammonium Chloride", "Methyltrioctylammonium Chloride", 
"Methyltrioctylammonium Chloride", "Harmane", "Harmane", "Harmane", 
"Harmane", "2,4-Dinitrophenol", "2,4-Dinitrophenol", "2,4-Dinitrophenol", 
"2,4-Dinitrophenol", "Chlorhexidine", "Chlorhexidine", "Chlorhexidine", 
"Chlorhexidine", "Umbelliferone", "Umbelliferone", "Umbelliferone", 
"Umbelliferone", "Cinnamic Acid (trans)", "Cinnamic Acid (trans)", 
"Cinnamic Acid (trans)", "Cinnamic Acid (trans)", "Disulphiram", 
"Disulphiram", "Disulphiram", "Disulphiram", "Iodonitro Tetrazolium Violet", 
"Iodonitro Tetrazolium Violet", "Iodonitro Tetrazolium Violet", 
"Iodonitro Tetrazolium Violet", "Phenyl-Methyl-Sulfonyl Fluoride", 
"Phenyl-Methyl-Sulfonyl Fluoride", "Phenyl-Methyl-Sulfonyl Fluoride", 
"Phenyl-Methyl-Sulfonyl Fluoride", "FCCP", "FCCP", "FCCP", "FCCP", 
"D,L-Thioctic Acid", "D,L-Thioctic Acid", "D,L-Thioctic Acid", 
"D,L-Thioctic Acid", "Lawsone", "Lawsone", "Lawsone", "Lawsone", 
"Phenethicillin", "Phenethicillin", "Phenethicillin", "Phenethicillin", 
"Blasticidin S", "Blasticidin S", "Blasticidin S", "Blasticidin S", 
"Sodium Caprylate", "Sodium Caprylate", "Sodium Caprylate", "Sodium Caprylate", 
"Lauryl Sulfobetaine", "Lauryl Sulfobetaine", "Lauryl Sulfobetaine", 
"Lauryl Sulfobetaine", "Dihydrostreptomycin", "Dihydrostreptomycin", 
"Dihydrostreptomycin", "Dihydrostreptomycin", "Hydroxylamine", 
"Hydroxylamine", "Hydroxylamine", "Hydroxylamine", "Hexaminecobalt (III) Chloride", 
"Hexaminecobalt (III) Chloride", "Hexaminecobalt (III) Chloride", 
"Hexaminecobalt (III) Chloride", "a-Thioglycerol", "a-Thioglycerol", 
"a-Thioglycerol", "a-Thioglycerol", "Polymyxin B", "Polymyxin B", 
"Polymyxin B", "Polymyxin B", "Amitriptyline", "Amitriptyline", 
"Amitriptyline", "Amitriptyline", "Apramycin", "Apramycin", "Apramycin", 
"Apramycin", "Benserazide", "Benserazide", "Benserazide", "Benserazide", 
"Orphenadrine", "Orphenadrine", "Orphenadrine", "Orphenadrine", 
"D,L-Propranolol", "D,L-Propranolol", "D,L-Propranolol", "D,L-Propranolol", 
"Tetrazolium Violet", "Tetrazolium Violet", "Tetrazolium Violet", 
"Tetrazolium Violet", "Thioridazine", "Thioridazine", "Thioridazine", 
"Thioridazine", "Atropine", "Atropine", "Atropine", "Atropine", 
"Ornidazole", "Ornidazole", "Ornidazole", "Ornidazole", "Proflavine", 
"Proflavine", "Proflavine", "Proflavine", "Ciprofloxacin", "Ciprofloxacin", 
"Ciprofloxacin", "Ciprofloxacin", "18-Crown-6-Ether", "18-Crown-6-Ether", 
"18-Crown-6-Ether", "18-Crown-6-Ether", "Crystal Violet", "Crystal Violet", 
"Crystal Violet", "Crystal Violet", "Dodine", "Dodine", "Dodine", 
"Dodine", "Hexachlorophene", "Hexachlorophene", "Hexachlorophene", 
"Hexachlorophene", "4-Hydroxycoumarin", "4-Hydroxycoumarin", 
"4-Hydroxycoumarin", "4-Hydroxycoumarin", "Oxytetracycline", 
"Oxytetracycline", "Oxytetracycline", "Oxytetracycline", "Pridinol", 
"Pridinol", "Pridinol", "Pridinol", "Captan", "Captan", "Captan", 
"Captan", "3,5-Dinitrobenzoic Acid", "3,5-Dinitrobenzoic Acid", 
"3,5-Dinitrobenzoic Acid", "3,5-Dinitrobenzoic Acid", "8-Hydroxyquinoline", 
"8-Hydroxyquinoline", "8-Hydroxyquinoline", "8-Hydroxyquinoline", 
"Patulin", "Patulin", "Patulin", "Patulin", "Tolylfluanid", "Tolylfluanid", 
"Tolylfluanid", "Tolylfluanid", "Troleandomycin", "Troleandomycin", 
"Troleandomycin", "Troleandomycin", "Negative Control", "Negative Control", 
"Negative Control", "a-Cyclodextrin", "Dextrin", "Glycogen", 
"Maltitol", "Maltotriose", "D-Maltose", "D-Trehalose", "D-Cellobiose", 
"b-Gentiobiose", "D-Glucose-6-Phosphate", "a-D-Glucose-1-Phosphate", 
"L-Glucose", "a-D-Glucose", "a-D-Glucose", "a-D-Glucose", "3-O-Methyl-D-Glucose", 
"a-Methyl-D-Glucoside", "b-Methyl-D-Glucoside", "D-Salicin", 
"D-Sorbitol", "N-Acetyl-D-Glucosamine", "D-Glucosaminic Acid", 
"D-Glucuronic Acid", "Chondroitin 6-Sulfate", "Mannan", "D-Mannose", 
"a-Methyl-D-Mannoside", "D-Mannitol", "N-Acetyl-b-D-Mannosamine", 
"D-Melezitose", "Sucrose", "Palatinose", "D-Turanose", "D-Tagatose", 
"L-Sorbose", "L-Rhamnose", "L-Fucose", "D-Fucose", "D-Fructose-6-Phosphate", 
"D-Fructose", "Stachyose", "D-Raffinose", "D-Lactitol", "Lactulose", 
"a-D-Lactose", "Melibionic Acid", "D-Melibiose", "D-Galactose", 
"a-Methyl-D-Galactoside", "b-Methyl-D-Galactoside", "N-Acetyl-Neuraminic Acid", 
"Pectin", "Sedoheptulosan", "Thymidine", "Uridine", "Adenosine", 
"Inosine", "Adonitol", "L-Arabinose", "D-Arabinose", "b-Methyl-D-Xylopyranoside", 
"Xylitol", "myo-Inositol", "m-Erythritol", "Propylene Glycol", 
"Ethanolamine", "D,L-a-Glycerol-Phosphate", "Glycerol", "Citric Acid", 
"Tricarballylic Acid", "D,L-Lactic Acid", "Methyl D-Lactate", 
"Methyl Pyruvate", "Pyruvic Acid", "a-Keto-Glutaric Acid", "Succinamic Acid", 
"Succinic Acid", "Mono-Methyl Succinate", "L-Malic Acid", "D-Malic Acid", 
"m-Tartaric Acid", "Lithium Acetoacetate", "g-Amino-N-Butyric Acid", 
"a-Keto-Butyric Acid", "a-Hydroxy-Butyric Acid", "b-Hydroxy-Butyric Acid", 
"g-Hydroxy-Butyric Acid", "Butyric Acid", "2,3-Butanediol", "3-Hydroxy-2-Butanone", 
"Propionic Acid", "Acetic Acid", "Hexanoic Acid", "Negative Control", 
"Negative Control", "Negative Control", "Tween 20", "Tween 40", 
"Tween 80", "Gelatin", "L-Alaninamide", "L-Alanine", "D-Alanine", 
"L-Arginine", "L-Asparagine", "L-Aspartic Acid", "D-Aspartic Acid", 
"L-Glutamic Acid", "D-Glutamic Acid", "L-Glutamine", "Glycine", 
"L-Histidine", "L-Homoserine", "Hydroxy-L-Proline", "L-Isoleucine", 
"L-Leucine", "L-Lysine", "L-Methionine", "L-Ornithine", "L-Phenylalanine", 
"L-Proline", "L-Serine", "D-Serine", "L-Threonine", "D-Threonine", 
"L-Tryptophan", "L-Tyrosine", "L-Valine", "Ala-Ala", "Ala-Arg", 
"Ala-Asn", "Ala-Asp", "Ala-Glu", "Ala-Gln", "Ala-Gly", "Ala-His", 
"Ala-Ile", "Ala-Leu", "Ala-Lys", "Ala-Met", "Ala-Phe", "Ala-Pro", 
"Ala-Ser", "Ala-Thr", "Ala-Trp", "Ala-Tyr", "Ala-Val", "Arg-Ala", 
"Arg-Arg", "Arg-Asp", "Arg-Gln", "Arg-Glu", "Arg-Ile", "Arg-Leu", 
"Arg-Lys", "Arg-Met", "Arg-Phe", "Arg-Ser", "Arg-Trp", "Arg-Tyr", 
"Arg-Val", "Asn-Glu", "Asn-Val", "Asp-Ala", "Asp-Asp", "Asp-Glu", 
"Asp-Gln", "Asp-Gly", "Asp-Leu", "Asp-Lys", "Asp-Phe", "Asp-Trp", 
"Asp-Val", "Glu-Ala", "Glu-Asp", "Glu-Glu", "Glu-Gly", "Glu-Ser", 
"Glu-Trp", "Glu-Tyr", "Glu-Val", "Gln-Glu", "Gln-Gln", "Gln-Gly", 
"Gly-Ala", "Gly-Arg", "Gly-Asn", "Gly-Asp", "a-D-Glucose", "Negative Control", 
"Negative Control", "Negative Control", "Gly-Gly", "Gly-His", 
"Gly-Ile", "Gly-Leu", "Gly-Lys", "Gly-Met", "Gly-Phe", "Gly-Pro", 
"Gly-Ser", "Gly-Thr", "Gly-Trp", "Gly-Tyr", "Gly-Val", "His-Ala", 
"His-Asp", "His-Glu", "His-Gly", "His-His", "His-Leu", "His-Lys", 
"His-Met", "His-Pro", "His-Ser", "His-Trp", "His-Tyr", "His-Val", 
"Ile-Ala", "Ile-Arg", "Ile-Asn", "Ile-Gln", "Ile-Gly", "Ile-His", 
"Ile-Ile", "Ile-Leu", "Ile-Met", "Ile-Phe", "Ile-Pro", "Ile-Ser", 
"Ile-Trp", "Ile-Tyr", "Ile-Val", "Leu-Ala", "Leu-Arg", "Leu-Asn", 
"Leu-Asp", "Leu-Glu", "Leu-Gly", "Leu-His", "Leu-Ile", "Leu-Leu", 
"Leu-Met", "Leu-Phe", "Leu-Pro", "Leu-Ser", "Leu-Trp", "Leu-Tyr", 
"Leu-Val", "Lys-Ala", "Lys-Arg", "Lys-Asp", "Lys-Glu", "Lys-Gly", 
"Lys-Ile", "Lys-Leu", "Lys-Lys", "Lys-Met", "Lys-Phe", "Lys-Pro", 
"Lys-Ser", "Lys-Thr", "Lys-Trp", "Lys-Tyr", "Lys-Val", "Met-Arg", 
"Met-Asp", "Met-Gln", "Met-Glu", "Met-Gly", "Met-His", "Met-Ile", 
"Met-Leu", "Met-Lys", "Met-Met", "Met-Phe", "Met-Pro", "Met-Thr", 
"Met-Trp", "Met-Tyr", "Met-Val", "Phe-Ala", "Phe-Asp", "Phe-Glu", 
"a-D-Glucose", "Negative Control", "Negative Control", "Negative Control", 
"Phe-Gly", "Phe-Ile", "Phe-Met", "Phe-Phe", "Phe-Pro", "Phe-Ser", 
"Phe-Trp", "Phe-Tyr", "Phe-Val", "Pro-Ala", "Pro-Arg", "Pro-Asn", 
"Pro-Asp", "Pro-Glu", "Pro-Gln", "Pro-Gly", "Pro-Hyp", "Pro-Ile", 
"Pro-Leu", "Pro-Lys", "Pro-Phe", "Pro-Pro", "Pro-Ser", "Pro-Trp", 
"Pro-Tyr", "Pro-Val", "Ser-Ala", "Ser-Asn", "Ser-Asp", "Ser-Glu", 
"Ser-Gln", "Ser-Gly", "Ser-His", "Ser-Leu", "Ser-Met", "Ser-Phe", 
"Ser-Pro", "Ser-Ser", "Ser-Tyr", "Ser-Val", "Thr-Ala", "Thr-Arg", 
"Thr-Asp", "Thr-Glu", "Thr-Gln", "Thr-Gly", "Thr-Leu", "Thr-Met", 
"Thr-Phe", "Thr-Pro", "Thr-Ser", "Trp-Ala", "Trp-Arg", "Trp-Asp", 
"Trp-Glu", "Trp-Gly", "Trp-Leu", "Trp-Lys", "Trp-Phe", "Trp-Ser", 
"Trp-Trp", "Trp-Tyr", "Trp-Val", "Tyr-Ala", "Tyr-Gln", "Tyr-Glu", 
"Tyr-Gly", "Tyr-His", "Tyr-Ile", "Tyr-Leu", "Tyr-Lys", "Tyr-Phe", 
"Tyr-Trp", "Tyr-Tyr", "Tyr-Val", "Val-Ala", "Val-Arg", "Val-Asn", 
"Val-Asp", "Val-Glu", "Val-Gln", "Val-Gly", "Val-His", "Val-Ile", 
"Val-Leu", "Val-Lys", "Val-Met", "Val-Phe", "Val-Pro", "Val-Ser", 
"Val-Tyr", "Val-Val", "a-D-Glucose", "Negative Control", "Negative Control", 
"Negative Control", "Negative Control", "NaCl", "NaCl", "NaCl", 
"NaCl", "NaCl", "NaCl", "NaCl", "NaCl", "Ammonium Chloride", 
"Ammonium Chloride", "Ammonium Chloride", "Ammonium Chloride", 
"Sodium Selenite", "Sodium Selenite", "Sodium Selenite", "Sodium Selenite", 
"Potassium Chloride", "Potassium Chloride", "Potassium Chloride", 
"Potassium Chloride", "Calcium Chloride", "Calcium Chloride", 
"Calcium Chloride", "Calcium Chloride", "Manganese Chloride", 
"Manganese Chloride", "Manganese Chloride", "Manganese Chloride", 
"Zinc Chloride", "Zinc Chloride", "Zinc Chloride", "Zinc Chloride", 
"Copper (II) Chloride", "Copper (II) Chloride", "Copper (II) Chloride", 
"Copper (II) Chloride", "Cobalt (II) Chloride", "Cobalt (II) Chloride", 
"Cobalt (II) Chloride", "Cobalt (II) Chloride", "Iodine", "Iodine", 
"Iodine", "Iodine", "Sodium Phosphate", "Sodium Phosphate", "Sodium Phosphate", 
"Sodium Phosphate", "Sodium Sulfate", "Sodium Sulfate", "Sodium Sulfate", 
"Sodium Sulfate", "Sodium Molybdate Dihydrate", "Sodium Molybdate Dihydrate", 
"Sodium Molybdate Dihydrate", "Sodium Molybdate Dihydrate", "Sodium Tungstate Dihydrate", 
"Sodium Tungstate Dihydrate", "Sodium Tungstate Dihydrate", "Sodium Tungstate Dihydrate", 
"Sodium Orthovanadate", "Sodium Orthovanadate", "Sodium Orthovanadate", 
"Sodium Orthovanadate", "Potassium Chromate", "Potassium Chromate", 
"Potassium Chromate", "Potassium Chromate", "Sodium Pyrophosphate", 
"Sodium Pyrophosphate", "Sodium Pyrophosphate", "Sodium Pyrophosphate", 
"Sodium Nitrate", "Sodium Nitrate", "Sodium Nitrate", "Sodium Nitrate", 
"Sodium Nitrite", "Sodium Nitrite", "Sodium Nitrite", "Sodium Nitrite", 
"Lithium Chloride", "Lithium Chloride", "Lithium Chloride", "Lithium Chloride", 
"Ferric Chloride", "Ferric Chloride", "Ferric Chloride", "Ferric Chloride", 
"Magnesium Chloride", "Magnesium Chloride", "Magnesium Chloride", 
"Magnesium Chloride", "Negative Control", "Negative Control", 
"Negative Control", "Negative Control", "Negative Control", "Negative Control", 
"Dibutyryl-cAMP", "Dibutyryl-cAMP", "Dibutyryl-cAMP", "Dibutyryl-cAMP", 
"Dibutyryl-cAMP", "Dibutyryl-cAMP", "3-Isobutyl-1-Methylxanthine", 
"3-Isobutyl-1-Methylxanthine", "3-Isobutyl-1-Methylxanthine", 
"3-Isobutyl-1-Methylxanthine", "3-Isobutyl-1-Methylxanthine", 
"3-Isobutyl-1-Methylxanthine", "Caffeine", "Caffeine", "Caffeine", 
"Caffeine", "Caffeine", "Caffeine", "Epinephrine", "Epinephrine", 
"Epinephrine", "Epinephrine", "Epinephrine", "Epinephrine", "Norepinephrine", 
"Norepinephrine", "Norepinephrine", "Norepinephrine", "Norepinephrine", 
"Norepinephrine", "L-Leucine", "L-Leucine", "L-Leucine", "L-Leucine", 
"L-Leucine", "L-Leucine", "Creatine", "Creatine", "Creatine", 
"Creatine", "Creatine", "Creatine", "Triiodothyronine", "Triiodothyronine", 
"Triiodothyronine", "Triiodothyronine", "Triiodothyronine", "Triiodothyronine", 
"Thyroxine", "Thyroxine", "Thyroxine", "Thyroxine", "Thyroxine", 
"Thyroxine", "Dexamethasone", "Dexamethasone", "Dexamethasone", 
"Dexamethasone", "Dexamethasone", "Dexamethasone", "Hydrocortisone", 
"Hydrocortisone", "Hydrocortisone", "Hydrocortisone", "Hydrocortisone", 
"Hydrocortisone", "Progesterone", "Progesterone", "Progesterone", 
"Progesterone", "Progesterone", "Progesterone", "b-Estradiol", 
"b-Estradiol", "b-Estradiol", "b-Estradiol", "b-Estradiol", "b-Estradiol", 
"4,5-a-Dihydrotestosterone", "4,5-a-Dihydrotestosterone", "4,5-a-Dihydrotestosterone", 
"4,5-a-Dihydrotestosterone", "4,5-a-Dihydrotestosterone", "4,5-a-Dihydrotestosterone", 
"Aldosterone", "Aldosterone", "Aldosterone", "Aldosterone", "Aldosterone", 
"Aldosterone", "Negative Control", "Negative Control", "Negative Control", 
"Negative Control", "Negative Control", "Negative Control", "Insulin", 
"Insulin", "Insulin", "Insulin", "Insulin", "Insulin", "Resistin", 
"Resistin", "Resistin", "Resistin", "Resistin", "Resistin", "Glucagon", 
"Glucagon", "Glucagon", "Glucagon", "Glucagon", "Glucagon", "Ghrelin", 
"Ghrelin", "Ghrelin", "Ghrelin", "Ghrelin", "Ghrelin", "Leptin", 
"Leptin", "Leptin", "Leptin", "Leptin", "Leptin", "Gastrin", 
"Gastrin", "Gastrin", "Gastrin", "Gastrin", "Gastrin", "Exendin-3", 
"Exendin-3", "Exendin-3", "Exendin-3", "Exendin-3", "Exendin-3", 
"hGH (Somatotropin)", "hGH (Somatotropin)", "hGH (Somatotropin)", 
"hGH (Somatotropin)", "hGH (Somatotropin)", "hGH (Somatotropin)", 
"IGF-I", "IGF-I", "IGF-I", "IGF-I", "IGF-I", "IGF-I", "FGF-1 (aFGF)", 
"FGF-1 (aFGF)", "FGF-1 (aFGF)", "FGF-1 (aFGF)", "FGF-1 (aFGF)", 
"FGF-1 (aFGF)", "PDGF-AB", "PDGF-AB", "PDGF-AB", "PDGF-AB", "PDGF-AB", 
"PDGF-AB", "IL-1b", "IL-1b", "IL-1b", "IL-1b", "IL-1b", "IL-1b", 
"IL-2", "IL-2", "IL-2", "IL-2", "IL-2", "IL-2", "IL-6", "IL-6", 
"IL-6", "IL-6", "IL-6", "IL-6", "IL-8", "IL-8", "IL-8", "IL-8", 
"IL-8", "IL-8", "Negative Control", "Negative Control", "Negative Control", 
"Negative Control", "Negative Control", "Negative Control", "Arginine-Vasopressin", 
"Arginine-Vasopressin", "Arginine-Vasopressin", "Arginine-Vasopressin", 
"Arginine-Vasopressin", "Arginine-Vasopressin", "Parathyroid Hormone", 
"Parathyroid Hormone", "Parathyroid Hormone", "Parathyroid Hormone", 
"Parathyroid Hormone", "Parathyroid Hormone", "Prolactin", "Prolactin", 
"Prolactin", "Prolactin", "Prolactin", "Prolactin", "Calcitonin", 
"Calcitonin", "Calcitonin", "Calcitonin", "Calcitonin", "Calcitonin", 
"Calcitriol (1a,25-dihydroxyvitamin D3)", "Calcitriol (1a,25-dihydroxyvitamin D3)", 
"Calcitriol (1a,25-dihydroxyvitamin D3)", "Calcitriol (1a,25-dihydroxyvitamin D3)", 
"Calcitriol (1a,25-dihydroxyvitamin D3)", "Calcitriol (1a,25-dihydroxyvitamin D3)", 
"Luteinizing Hormone (LH)", "Luteinizing Hormone (LH)", "Luteinizing Hormone (LH)", 
"Luteinizing Hormone (LH)", "Luteinizing Hormone (LH)", "Luteinizing Hormone (LH)", 
"Luteinizing Hormone Releasing Hormone (LH-RH)", "Luteinizing Hormone Releasing Hormone (LH-RH)", 
"Luteinizing Hormone Releasing Hormone (LH-RH)", "Luteinizing Hormone Releasing Hormone (LH-RH)", 
"Luteinizing Hormone Releasing Hormone (LH-RH)", "Luteinizing Hormone Releasing Hormone (LH-RH)", 
"Chorionic Gonadotropin Human (HCG)", "Chorionic Gonadotropin Human (HCG)", 
"Chorionic Gonadotropin Human (HCG)", "Chorionic Gonadotropin Human (HCG)", 
"Chorionic Gonadotropin Human (HCG)", "Chorionic Gonadotropin Human (HCG)", 
"Adrenocorticotropic Hormone Human (ACTH)", "Adrenocorticotropic Hormone Human (ACTH)", 
"Adrenocorticotropic Hormone Human (ACTH)", "Adrenocorticotropic Hormone Human (ACTH)", 
"Adrenocorticotropic Hormone Human (ACTH)", "Adrenocorticotropic Hormone Human (ACTH)", 
"Thyrotropic Hormone (TSH)", "Thyrotropic Hormone (TSH)", "Thyrotropic Hormone (TSH)", 
"Thyrotropic Hormone (TSH)", "Thyrotropic Hormone (TSH)", "Thyrotropic Hormone (TSH)", 
"Thyrotropin Releasing Hormone Acetate Salt (TRH)", "Thyrotropin Releasing Hormone Acetate Salt (TRH)", 
"Thyrotropin Releasing Hormone Acetate Salt (TRH)", "Thyrotropin Releasing Hormone Acetate Salt (TRH)", 
"Thyrotropin Releasing Hormone Acetate Salt (TRH)", "Thyrotropin Releasing Hormone Acetate Salt (TRH)", 
"IFN-g", "IFN-g", "IFN-g", "IFN-g", "IFN-g", "IFN-g", "TNF-a", 
"TNF-a", "TNF-a", "TNF-a", "TNF-a", "TNF-a", "Adenosine", "Adenosine", 
"Adenosine", "Adenosine", "Adenosine", "Adenosine", "Gly-His-Lys Acetate Salt", 
"Gly-His-Lys Acetate Salt", "Gly-His-Lys Acetate Salt", "Gly-His-Lys Acetate Salt", 
"Gly-His-Lys Acetate Salt", "Gly-His-Lys Acetate Salt", "No Chemical", 
"No Chemical", "No Chemical", "No Chemical", "Solasodine", "Solasodine", 
"Solasodine", "Solasodine", "Rotenone", "Rotenone", "Rotenone", 
"Rotenone", "Aklavine Hydrochloride", "Aklavine Hydrochloride", 
"Aklavine Hydrochloride", "Aklavine Hydrochloride", "Deguelin (-)", 
"Deguelin (-)", "Deguelin (-)", "Deguelin (-)", "Celastrol", 
"Celastrol", "Celastrol", "Celastrol", "Juglone", "Juglone", 
"Juglone", "Juglone", "Sanguinarine Sulfate", "Sanguinarine Sulfate", 
"Sanguinarine Sulfate", "Sanguinarine Sulfate", "Dactinomycin", 
"Dactinomycin", "Dactinomycin", "Dactinomycin", "Methylmethane Sulfonate", 
"Methylmethane Sulfonate", "Methylmethane Sulfonate", "Methylmethane Sulfonate", 
"Azathioprine", "Azathioprine", "Azathioprine", "Azathioprine", 
"Busulfan", "Busulfan", "Busulfan", "Busulfan", "Aclarubicin", 
"Aclarubicin", "Aclarubicin", "Aclarubicin", "Chloramphenicol", 
"Chloramphenicol", "Chloramphenicol", "Chloramphenicol", "Chloroquine Diphosphate", 
"Chloroquine Diphosphate", "Chloroquine Diphosphate", "Chloroquine Diphosphate", 
"Cyclophosphamide Hydrate", "Cyclophosphamide Hydrate", "Cyclophosphamide Hydrate", 
"Cyclophosphamide Hydrate", "Diethylcarbamazine Citrate", "Diethylcarbamazine Citrate", 
"Diethylcarbamazine Citrate", "Diethylcarbamazine Citrate", "Emetine Hydrochloride", 
"Emetine Hydrochloride", "Emetine Hydrochloride", "Emetine Hydrochloride", 
"Fluorouracil", "Fluorouracil", "Fluorouracil", "Fluorouracil", 
"Hydroxyurea", "Hydroxyurea", "Hydroxyurea", "Hydroxyurea", "Mechlorethamine", 
"Mechlorethamine", "Mechlorethamine", "Mechlorethamine", "Mercaptopurine", 
"Mercaptopurine", "Mercaptopurine", "Mercaptopurine", "Quinacrine Hydrochloride", 
"Quinacrine Hydrochloride", "Quinacrine Hydrochloride", "Quinacrine Hydrochloride", 
"Streptozosin", "Streptozosin", "Streptozosin", "Streptozosin", 
"No Chemical", "No Chemical", "No Chemical", "No Chemical", "Tamoxifen Citrate", 
"Tamoxifen Citrate", "Tamoxifen Citrate", "Tamoxifen Citrate", 
"Thioguanine", "Thioguanine", "Thioguanine", "Thioguanine", "Acriflavinium Hydrochloride", 
"Acriflavinium Hydrochloride", "Acriflavinium Hydrochloride", 
"Acriflavinium Hydrochloride", "Pentamidine Isethionate", "Pentamidine Isethionate", 
"Pentamidine Isethionate", "Pentamidine Isethionate", "Mycophenolic Acid", 
"Mycophenolic Acid", "Mycophenolic Acid", "Mycophenolic Acid", 
"Aminopterin", "Aminopterin", "Aminopterin", "Aminopterin", "Berberine Chloride", 
"Berberine Chloride", "Berberine Chloride", "Berberine Chloride", 
"Emodin", "Emodin", "Emodin", "Emodin", "Puromycin Hydrochloride", 
"Puromycin Hydrochloride", "Puromycin Hydrochloride", "Puromycin Hydrochloride", 
"Neriifolin", "Neriifolin", "Neriifolin", "Neriifolin", "5-Fluoro-5'-Deoxyuridine", 
"5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", 
"Carboplatin", "Carboplatin", "Carboplatin", "Carboplatin", "Cisplatin", 
"Cisplatin", "Cisplatin", "Cisplatin", "Zidovudine (AZT)", "Zidovudine (AZT)", 
"Zidovudine (AZT)", "Zidovudine (AZT)", "Azacytidine", "Azacytidine", 
"Azacytidine", "Azacytidine", "Cycloheximide", "Cycloheximide", 
"Cycloheximide", "Cycloheximide", "Azaserine", "Azaserine", "Azaserine", 
"Azaserine", "p-Fluorophenylalanine", "p-Fluorophenylalanine", 
"p-Fluorophenylalanine", "p-Fluorophenylalanine", "1,2-Dimethylhydrazine Hydrochloride", 
"1,2-Dimethylhydrazine Hydrochloride", "1,2-Dimethylhydrazine Hydrochloride", 
"1,2-Dimethylhydrazine Hydrochloride", "Phenethyl Caffeate (CAPE)", 
"Phenethyl Caffeate (CAPE)", "Phenethyl Caffeate (CAPE)", "Phenethyl Caffeate (CAPE)", 
"Camptothecin", "Camptothecin", "Camptothecin", "Camptothecin", 
"Amygdalin", "Amygdalin", "Amygdalin", "Amygdalin", "Ellagic Acid", 
"Ellagic Acid", "Ellagic Acid", "Ellagic Acid", "No Chemical", 
"No Chemical", "No Chemical", "No Chemical", "Monocrotaline", 
"Monocrotaline", "Monocrotaline", "Monocrotaline", "Altretamine", 
"Altretamine", "Altretamine", "Altretamine", "Carmustine", "Carmustine", 
"Carmustine", "Carmustine", "Mitoxantrone Hydrochloride", "Mitoxantrone Hydrochloride", 
"Mitoxantrone Hydrochloride", "Mitoxantrone Hydrochloride", "Urethane", 
"Urethane", "Urethane", "Urethane", "Thiotepa", "Thiotepa", "Thiotepa", 
"Thiotepa", "Thiodiglycol", "Thiodiglycol", "Thiodiglycol", "Thiodiglycol", 
"Pipobroman", "Pipobroman", "Pipobroman", "Pipobroman", "Etanidazole", 
"Etanidazole", "Etanidazole", "Etanidazole", "Semustine", "Semustine", 
"Semustine", "Semustine", "Gossypol", "Gossypol", "Gossypol", 
"Gossypol", "Formestane", "Formestane", "Formestane", "Formestane", 
"Ancitabine Hydrochloride", "Ancitabine Hydrochloride", "Ancitabine Hydrochloride", 
"Ancitabine Hydrochloride", "Nimustine", "Nimustine", "Nimustine", 
"Nimustine", "Aminolevulinic Acid Hydrochloride", "Aminolevulinic Acid Hydrochloride", 
"Aminolevulinic Acid Hydrochloride", "Aminolevulinic Acid Hydrochloride", 
"Picropodophyllotoxin", "Picropodophyllotoxin", "Picropodophyllotoxin", 
"Picropodophyllotoxin", "b-Peltatin", "b-Peltatin", "b-Peltatin", 
"b-Peltatin", "Perillyl Alcohol", "Perillyl Alcohol", "Perillyl Alcohol", 
"Perillyl Alcohol", "Dibenzoylmethane", "Dibenzoylmethane", "Dibenzoylmethane", 
"Dibenzoylmethane", "6-Aminonicotinamide", "6-Aminonicotinamide", 
"6-Aminonicotinamide", "6-Aminonicotinamide", "Carmofur", "Carmofur", 
"Carmofur", "Carmofur", "Indole-3-Carbinol", "Indole-3-Carbinol", 
"Indole-3-Carbinol", "Indole-3-Carbinol", "Rifaximin", "Rifaximin", 
"Rifaximin", "Rifaximin", "No Chemical", "No Chemical", "No Chemical", 
"No Chemical", "Cepharanthine", "Cepharanthine", "Cepharanthine", 
"Cepharanthine", "4'-Demethylepipodophyllotoxin", "4'-Demethylepipodophyllotoxin", 
"4'-Demethylepipodophyllotoxin", "4'-Demethylepipodophyllotoxin", 
"Miltefosine", "Miltefosine", "Miltefosine", "Miltefosine", "Elaidylphosphocholine", 
"Elaidylphosphocholine", "Elaidylphosphocholine", "Elaidylphosphocholine", 
"Podofilox", "Podofilox", "Podofilox", "Podofilox", "Colchicine", 
"Colchicine", "Colchicine", "Colchicine", "Methotrexate", "Methotrexate", 
"Methotrexate", "Methotrexate", "Acivicin", "Acivicin", "Acivicin", 
"Acivicin", "Floxuridine", "Floxuridine", "Floxuridine", "Floxuridine", 
"Lefunomide", "Lefunomide", "Lefunomide", "Lefunomide", "Rapamycin", 
"Rapamycin", "Rapamycin", "Rapamycin", "13-cis Retinoic Acid", 
"13-cis Retinoic Acid", "13-cis Retinoic Acid", "13-cis Retinoic Acid", 
"all-trans Retinoic Acid", "all-trans Retinoic Acid", "all-trans Retinoic Acid", 
"all-trans Retinoic Acid", "Piceatannol", "Piceatannol", "Piceatannol", 
"Piceatannol", "(+)-Catechin Hydrate", "(+)-Catechin Hydrate", 
"(+)-Catechin Hydrate", "(+)-Catechin Hydrate", "Mitomycin C", 
"Mitomycin C", "Mitomycin C", "Mitomycin C", "Cytosine-b-D-arabinofuranoside", 
"Cytosine-b-D-arabinofuranoside", "Cytosine-b-D-arabinofuranoside", 
"Cytosine-b-D-arabinofuranoside", "Daunorubicin Hydrochloride", 
"Daunorubicin Hydrochloride", "Daunorubicin Hydrochloride", "Daunorubicin Hydrochloride", 
"Doxorubicin Hydrochloride", "Doxorubicin Hydrochloride", "Doxorubicin Hydrochloride", 
"Doxorubicin Hydrochloride", "Etoposide", "Etoposide", "Etoposide", 
"Etoposide", "Nocodazole", "Nocodazole", "Nocodazole", "Nocodazole", 
"Quercetin Dihydrate", "Quercetin Dihydrate", "Quercetin Dihydrate", 
"Quercetin Dihydrate", "Vinblastine Sulfate", "Vinblastine Sulfate", 
"Vinblastine Sulfate", "Vinblastine Sulfate"), .Dim = c(96L, 
33L), .Dimnames = list(c("A01", "A02", "A03", "A04", "A05", "A06", 
"A07", "A08", "A09", "A10", "A11", "A12", "B01", "B02", "B03", 
"B04", "B05", "B06", "B07", "B08", "B09", "B10", "B11", "B12", 
"C01", "C02", "C03", "C04", "C05", "C06", "C07", "C08", "C09", 
"C10", "C11", "C12", "D01", "D02", "D03", "D04", "D05", "D06", 
"D07", "D08", "D09", "D10", "D11", "D12", "E01", "E02", "E03", 
"E04", "E05", "E06", "E07", "E08", "E09", "E10", "E11", "E12", 
"F01", "F02", "F03", "F04", "F05", "F06", "F07", "F08", "F09", 
"F10", "F11", "F12", "G01", "G02", "G03", "G04", "G05", "G06", 
"G07", "G08", "G09", "G10", "G11", "G12", "H01", "H02", "H03", 
"H04", "H05", "H06", "H07", "H08", "H09", "H10", "H11", "H12"
), c("Gen III", "PM01", "PM02", "PM03", "PM04", "PM05", "PM06", 
"PM07", "PM08", "PM09", "PM10", "PM11", "PM12", "PM13", "PM14", 
"PM15", "PM16", "PM17", "PM18", "PM19", "PM20", "PM-M01", "PM-M02", 
"PM-M03", "PM-M04", "PM-M05", "PM-M06", "PM-M07", "PM-M08", "PM-M11", 
"PM-M12", "PM-M13", "PM-M14")))
